@@ -1,6 +1,16 @@
 # (C) Copyright 2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
-import contextlib
 import logging
 import os
 import psutil
@@ -45,9 +55,8 @@ class TestProcessCheck(unittest.TestCase):
         isfile_patch = patch.object(os.path, 'isfile',
                                     return_value=config_is_file)
 
-        with contextlib.nested(process_iter_patch,
-                               isfile_patch) as (
-                mock_process_iter, mock_isfile):
+        with process_iter_patch as mock_process_iter, \
+                isfile_patch as mock_isfile:
             proc_plugin._detect()
             if by_process_name:
                 self.assertTrue(mock_process_iter.called)
@@ -148,10 +157,11 @@ class TestProcessCheck(unittest.TestCase):
                          'vertica')
 
     def test_input_yaml_file(self):
-        # note: The previous tests will cover all yaml data variations, since the data is translated into a single dictionary.
-        fd, temp_path = tempfile.mkstemp(suffix='.yaml')
-        os.write(fd, '---\nprocess_config:\n- process_username: dbadmin\n  dimensions:\n    '
-                 'service: monitoring\n    component: vertica\n')
+        # note: The previous tests will cover all yaml data variations, since
+        # the data is translated into a single dictionary.
+        fd, temp_path = tempfile.mkstemp(suffix='.yaml', text=True)
+        os.write(fd, b'---\nprocess_config:\n- process_username: dbadmin\n  dimensions:\n    '
+                 b'service: monitoring\n    component: vertica\n')
         self.proc_plugin.args = {'conf_file_path': temp_path}
         self.proc_plugin._detect()
         result = self.proc_plugin.build_config()
